%plotScreenSimulations A script to create the figures in Katzin et al., Radiometric properties of screens and energy saving in greenhouses
%
% This script file should be run from its directory, i.e., the active directory in
% MATLAB should be ...\Scripts\

% David Katzin, Wageningen University and Research, July 2024
% david.katzin@wur.nl


%% Default settings

% Uncomment the next line if you want to close the figures generted by MATLAB
% keepFigsOpen = false;

% Uncomment the next line to prevent MATLAB from saving the generated figures and data
% saveFigs = false;

if ~exist('keepFigsOpen', 'var') || isempty(keepFigsOpen)
    keepFigsOpen = true;
end

if ~exist('saveFigs', 'var') || isempty(saveFigs)
    saveFigs = true;
end


%% Set up directories

% Find the full path of the this file's directory.
currentFilename = mfilename();
fullFilePath = mfilename('fullpath');
currentFileDir = strrep(fullFilePath, currentFilename, '');

if isempty(currentFileDir) || contains(currentFileDir, 'Temp\Editor') % This script is run from the console
    currentFileDir = [cd() '\']; % the directory from which this script is running
end

origDirSlashes = strfind(currentFileDir,'\');
upDir = currentFileDir(1:origDirSlashes(end-1)); % Up one level from currentFileDir

% Location of simulation results: upDir\Simulation results\
simResultsDir =  [upDir 'Simulation results\'];

% Location of figures directory: upDir\Figures\
figuresDir =  [upDir 'Figures\'];

if ~exist(figuresDir, 'dir')
    mkdir(figuresDir);
end

% Create subdirectories: png, fig, csv
if ~exist([figuresDir 'png\'], 'dir')
    mkdir([figuresDir 'png\']);
end
if ~exist([figuresDir 'fig\'], 'dir')
    mkdir([figuresDir 'fig\']);
end
if ~exist([figuresDir 'csv\'], 'dir')
    mkdir([figuresDir 'csv\']);
end

%% Figure settings and useful variables
fontSize = 10;
lineWidth = 0.8;
figSize = [20 10]; % [width height]    

% Default color scheme of MATLAB
cc = lines();

%% First simulation set - load data
% Variables for storing:
%   gas use (m3/m2/year)
%   yield (kg/m2/year)
%   EUE (kg/m3)
epsUpTau30 = nan(3,9); % variable eps up, tauTir fixed at 30%
epsDnTau30 = nan(3,9); % variable eps down, tauTir fixed at 30%
tauTirEps50 = nan(3,9); % variable tauTir, eps fixed at 50%
tauParAbs10 = nan(3,9); % variable tauPar, aPar fixed at 10%
tauNirAbs10 = nan(3,9); % varial tauNir, aNir fixed at 10%

% Create a cell with all relevant file names
fileNames = dir([simResultsDir 'First simulation set']);
fileNames = fileNames(3:end);
fileNames = struct2cell(fileNames);
fileNames = fileNames(1,:);

fieldNames = readmatrix([simResultsDir 'First simulation set\' fileNames{1}], ...
    'range','1:1','outputtype','char');

f = struct; % numerical reference to fields
for n=1:numel(fieldNames)
    fieldName = fieldNames{n};
    fieldName = strrep(fieldName, '%', '');
    
    f.(fieldNames{n}) = n;
end

for iiFile = 1:numel(fileNames)
    name = char(fileNames(iiFile));
    if length(name) == 28
        fprintf('Reading file %s\n', name);
        csvRead = readmatrix([simResultsDir 'First simulation set\' fileNames{iiFile}]);
        if regexp(name, 'eps_up\w*.\w*tau0.3') % variable eps up, tauTir fixed
            var = str2double(name(8:10));
            epsUpTau30(1, round(var*10)) = sum(3600e-6*csvRead(:,f.heating));
            epsUpTau30(2, round(var*10)) = csvRead(end,f.cumulativeHarvest);
            epsUpTau30(3, round(var*10)) = 1000*epsUpTau30(2, round(var*10))./epsUpTau30(1, round(var*10));
        elseif regexp(name, 'eps_dn\w*.\w*tau0.3') % variable eps dn, tauTir fixed
            var = str2double(name(8:10));
            epsDnTau30(1, round(var*10)) = sum(3600e-6*csvRead(:,f.heating));
            epsDnTau30(2, round(var*10)) = csvRead(end,f.cumulativeHarvest);
            epsDnTau30(3, round(var*10)) = 1000*epsDnTau30(2, round(var*10))./epsDnTau30(1, round(var*10));
        elseif regexp(name, 'tauTir\w*.\w*eps0.5') % variabl tauTir, epsTir fixed
            var = str2double(name(8:10));
            tauTirEps50(1, round(var*10)) = sum(3600e-6*csvRead(:,f.heating));
            tauTirEps50(2, round(var*10)) = csvRead(end,f.cumulativeHarvest);
            tauTirEps50(3, round(var*10)) = 1000*tauTirEps50(2, round(var*10))./tauTirEps50(1, round(var*10));
        elseif regexp(name, 'tauPar\w*.\w*abs0.1') % Variable tauPar, absPar fixed
            var = str2double(name(8:10));
            tauParAbs10(1, round(var*10)) = sum(3600e-6*csvRead(:,f.heating));
            tauParAbs10(2, round(var*10)) = csvRead(end,f.cumulativeHarvest);
            tauParAbs10(3, round(var*10)) = 1000*tauParAbs10(2, round(var*10))./tauParAbs10(1, round(var*10));
        elseif regexp(name, 'tauNir\w*.\w*abs0.1') % Variable tauNir, absNir fixed
            var = str2double(name(8:10));
            tauNirAbs10(1, round(var*10)) = sum(3600e-6*csvRead(:,f.heating));
            tauNirAbs10(2, round(var*10)) = csvRead(end,f.cumulativeHarvest);
            tauNirAbs10(3, round(var*10)) = 1000*tauNirAbs10(2, round(var*10))./tauNirAbs10(1, round(var*10));
        end
    end
end



%% Second simulation set - load data

% Variables for storing:
%   gas use (m3/m2/year)
%   yield (kg/m2/year)
%   EUE (kg/m3)
%   Number of screen hours (hours/year)
%   PAR above the crop (mol/m2/year)
tauParAbs10Mod = nan(5,9); % variable taupar, fixed abs, modified screen strategy
tauParLoNirAbs10Mod = nan(5,9); % variable taupar, fixed abs, low tau nir, modified screen strategy
tauParNirAbs10Mod = nan(5,9); % variable taupar and taunir, fixed abs, modified screen strategy
tauParLoEAbs10Mod = nan(5,9); % variable taupar, fixed abs, low tau nir, modified screen strategy

% Create a cell with all relevant file names
fileNames = dir([simResultsDir 'Second simulation set']);
fileNames = fileNames(3:end);
fileNames = struct2cell(fileNames);
fileNames = fileNames(1,:);

for iiFile = 1:numel(fileNames)
    name = char(fileNames(iiFile));
    fprintf('Reading file %s\n', name);
    csvRead = readmatrix([simResultsDir 'Second simulation set\' fileNames{iiFile}]);
    name = strrep(name, '_output.csv', '');
    if length(name) == 29 && ~isempty(regexp(name, 'tauPar\w*.\w*abs0.1_modStrategy', 'once')) 
        var = str2double(name(8:10));
        tauParAbs10Mod(1, round(var*10)) = sum(3600e-6*csvRead(:,f.heating));
        tauParAbs10Mod(2, round(var*10)) = csvRead(end,f.cumulativeHarvest);
        tauParAbs10Mod(3, round(var*10)) = 1000*tauParAbs10Mod(2, round(var*10))./tauParAbs10Mod(1, round(var*10));
        tauParAbs10Mod(4, round(var*10)) = sum(csvRead(:,f.scrPos)); % Screen hours
        tauParAbs10Mod(5, round(var*10)) = sum(3600e-6*csvRead(:,f.parIn)); % PAR sum above crop
    elseif length(name) == 39 && ~isempty(regexp(name, 'tauPar\w*.\w*abs0.1_modStrategy_lowTauNir', 'once')) 
        var = str2double(name(8:10));
        tauParLoNirAbs10Mod(1, round(var*10)) = sum(3600e-6*csvRead(:,f.heating));
        tauParLoNirAbs10Mod(2, round(var*10)) = csvRead(end,f.cumulativeHarvest);
        tauParLoNirAbs10Mod(3, round(var*10)) = 1000*tauParLoNirAbs10Mod(2, round(var*10))./tauParLoNirAbs10Mod(1, round(var*10));
        tauParLoNirAbs10Mod(4, round(var*10)) = sum(csvRead(:,f.scrPos)); % Screen hours
        tauParLoNirAbs10Mod(5, round(var*10)) = sum(3600e-6*csvRead(:,f.parIn)); % PAR sum above crop
    elseif length(name) == 32 && ~isempty(regexp(name, 'tauParNir\w*.\w*abs0.1_modStrategy', 'once')) 
        var = str2double(name(11:13));
        tauParNirAbs10Mod(1, round(var*10)) = sum(3600e-6*csvRead(:,f.heating));
        tauParNirAbs10Mod(2, round(var*10)) = csvRead(end,f.cumulativeHarvest);
        tauParNirAbs10Mod(3, round(var*10)) = 1000*tauParNirAbs10Mod(2, round(var*10))./tauParNirAbs10Mod(1, round(var*10));
        tauParNirAbs10Mod(4, round(var*10)) = sum(csvRead(:,f.scrPos)); % Screen hours
        tauParNirAbs10Mod(5, round(var*10)) = sum(3600e-6*csvRead(:,f.parIn)); % PAR sum above crop
    elseif length(name) == 34 && ~isempty(regexp(name, 'tauPar\w*.\w*abs0.1_modStrategy_lowE', 'once')) 
        var = str2double(name(8:10));
        tauParLoEAbs10Mod(1, round(var*10)) = sum(3600e-6*csvRead(:,f.heating));
        tauParLoEAbs10Mod(2, round(var*10)) = csvRead(end,f.cumulativeHarvest);
        tauParLoEAbs10Mod(3, round(var*10)) = 1000*tauParLoEAbs10Mod(2, round(var*10))./tauParLoEAbs10Mod(1, round(var*10));
        tauParLoEAbs10Mod(4, round(var*10)) = sum(csvRead(:,f.scrPos)); % Screen hours
        tauParLoEAbs10Mod(5, round(var*10)) = sum(3600e-6*csvRead(:,f.parIn)); % PAR sum above crop
    end
end


%% First simulation set: gas use - same screen strategy
figFileName = 'gasUse';
fig = figure('InvertHardcopy','off','Color',[1 1 1]);
csvData = [];
hold on

p = plot(0.1:0.1:0.9, epsUpTau30(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, epsDnTau30(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauTirEps50(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParAbs10(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauNirAbs10(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(5,:)); 
csvData = [csvData p.YData'];

legend('$\varepsilon^{Up}$', ...
       '$\varepsilon^{Dn}$', ...
       '$\tau_{TIR}$', ...
       '$\tau_{PAR}$', ...
       '$\tau_{NIR}$', ...
       'FontSize',fontSize,'Location','ne', 'Interpreter', 'latex');

title('Energy use for heating with modified screen parameters','FontSize',fontSize);
ylabel('Energy use (MJ m^{-2} year^{-1})')
xlabel('Modified parameter value (at the expense of reflection)')
grid
set(gca,'FontSize',fontSize-2)
ylim([1000 1300])

fig.Units = 'centimeters';
fig.OuterPosition(3)=figSize(1);
fig.OuterPosition(4)=figSize(2);

% Save figure to png, fig, and csv
if saveFigs
    exportgraphics(fig,[figuresDir 'png\' figFileName '.png']);
    savefig(fig,[figuresDir 'fig\' figFileName '.fig'],'compact');
    writematrix(csvData, [figuresDir 'csv\' figFileName '.csv']);
end
    
if ~keepFigsOpen
    close(fig);
end

%% First simulation set: yield - same screen strategy
figFileName = 'yield';
fig = figure('InvertHardcopy','off','Color',[1 1 1]);
csvData = [];
hold on

p = plot(0.1:0.1:0.9, epsUpTau30(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, epsDnTau30(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauTirEps50(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParAbs10(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauNirAbs10(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(5,:)); 
csvData = [csvData p.YData'];

legend('$\varepsilon^{Up}$', ...
       '$\varepsilon^{Dn}$', ...
       '$\tau_{TIR}$', ...
       '$\tau_{PAR}$', ...
       '$\tau_{NIR}$', ...
       'FontSize',fontSize,'Location','se', 'Interpreter', 'latex');

title('Total yield with modified screen parameters','FontSize',fontSize);
ylabel('Total yield (kg FW m^{-2} year^{-1})')
xlabel('Modified parameter value (at the expense of reflection)')
grid
set(gca,'FontSize',fontSize-2)
ylim([58 66])

fig.Units = 'centimeters';
fig.OuterPosition(3)=figSize(1);
fig.OuterPosition(4)=figSize(2);

% Save figure to png, fig, and csv
if saveFigs
    exportgraphics(fig,[figuresDir 'png\' figFileName '.png']);
    savefig(fig,[figuresDir 'fig\' figFileName '.fig'],'compact');
    writematrix(csvData, [figuresDir 'csv\' figFileName '.csv']);
end
    
if ~keepFigsOpen
    close(fig);
end

%% First simulation set: EUE - same screen strategy
figFileName = 'eue';
fig = figure('InvertHardcopy','off','Color',[1 1 1]);
csvData = [];
hold on

p = plot(0.1:0.1:0.9, epsUpTau30(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, epsDnTau30(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauTirEps50(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParAbs10(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauNirAbs10(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(5,:)); 
csvData = [csvData p.YData'];

legend('$\varepsilon^{Up}$', ...
       '$\varepsilon^{Dn}$', ...
       '$\tau_{TIR}$', ...
       '$\tau_{PAR}$', ...
       '$\tau_{NIR}$', ...
       'FontSize',fontSize,'Location','ne', 'Interpreter', 'latex');

title('Energy use efficiency with modified screen parameters','FontSize',fontSize);
ylabel('Energy use efficiency (g FW MJ^{-1})')
xlabel('Modified parameter value (at the expense of reflection)')
grid
set(gca,'FontSize',fontSize-2)
ylim([52 64])

fig.Units = 'centimeters';
fig.OuterPosition(3)=figSize(1);
fig.OuterPosition(4)=figSize(2);

% Save figure to png, fig, and csv
if saveFigs
    exportgraphics(fig,[figuresDir 'png\' figFileName '.png']);
    savefig(fig,[figuresDir 'fig\' figFileName '.fig'],'compact');
    writematrix(csvData, [figuresDir 'csv\' figFileName '.csv']);
end
    
if ~keepFigsOpen
    close(fig);
end

%% First simulation set: gas use, yield, and EUE - same screen strategy
% Figure 1 in Katzin et al., Radiative properties of screens and energy saving in greenhouses
figFileName = 'Figure1_gasYieldEue';
fig = figure('InvertHardcopy','off','Color',[1 1 1]);
csvData = [];

subplot(3,1,1)
hold on

p = plot(0.1:0.1:0.9, epsUpTau30(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, epsDnTau30(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauTirEps50(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParAbs10(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauNirAbs10(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(5,:)); 
csvData = [csvData p.YData'];

title('A. Energy use for heating with modified screen parameters','FontSize',fontSize);
ylabel('Energy use (MJ m^{-2} year^{-1})')
grid
set(gca,'FontSize',fontSize-2)
ylim([1000 1300])

subplot(3,1,2)
hold on

p = plot(0.1:0.1:0.9, epsUpTau30(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, epsDnTau30(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauTirEps50(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParAbs10(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauNirAbs10(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(5,:)); 
csvData = [csvData p.YData'];

legend('$\varepsilon^{Up}$', ...
       '$\varepsilon^{Dn}$', ...
       '$\tau_{TIR}$', ...
       '$\tau_{PAR}$', ...
       '$\tau_{NIR}$', ...
       'FontSize',fontSize,'Location','se', 'Interpreter', 'latex');

title('B. Total yield with modified screen parameters','FontSize',fontSize);
ylabel('Total yield (kg FW m^{-2} year^{-1})')
grid
set(gca,'FontSize',fontSize-2)
ylim([58 66])

% EUE - same screen strategy
subplot(3,1,3);
hold on

p = plot(0.1:0.1:0.9, epsUpTau30(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, epsDnTau30(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauTirEps50(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParAbs10(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauNirAbs10(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(5,:)); 
csvData = [csvData p.YData'];

title('C. Energy use efficiency with modified screen parameters','FontSize',fontSize);
ylabel('Energy use efficiency (g FW MJ^{-1})')
xlabel('Modified parameter value (at the expense of reflection)')
grid
set(gca,'FontSize',fontSize-2)
ylim([52 64])

fig.Units = 'centimeters';
fig.OuterPosition(3)=figSize(1);
fig.OuterPosition(4)=figSize(2)*2;

% Save figure to png, fig, and csv
if saveFigs
    exportgraphics(fig,[figuresDir 'png\' figFileName '.png']);
    savefig(fig,[figuresDir 'fig\' figFileName '.fig'],'compact');
    writematrix(csvData, [figuresDir 'csv\' figFileName '.csv']);
end
    
if ~keepFigsOpen
    close(fig);
end

%% Second simulation set: gas use - varying screen strategy
figFileName = 'gasUse_modStrategy';
fig = figure('InvertHardcopy','off','Color',[1 1 1]);
csvData = [];
hold on

p = plot(0.1:0.1:0.9, tauParAbs10Mod(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParNirAbs10Mod(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoNirAbs10Mod(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoEAbs10Mod(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];


legend('$\tau_{PAR}$', ...
       '$\tau_{PAR}$ and $\tau_{NIR}$', ...
       '$\tau_{PAR}$ ($\tau_{NIR}$ = 0.3)', ...
       '$\tau_{PAR}$ ($\varepsilon^{Up}$ = 0.2)', ...
       'FontSize',fontSize, 'Location', 'ne', 'Interpreter', 'latex', 'NumColumns', 2);

ylabel('Energy use (MJ m^{-2} year^{-1})')

title('Energy use with PAR transmission modified','FontSize',fontSize);
xlabel('Modified parameter value (at the expense of reflection)')
grid
set(gca,'FontSize',fontSize-2)
ylim([1000 1300])

fig.Units = 'centimeters';
fig.OuterPosition(3)=figSize(1);
fig.OuterPosition(4)=figSize(2);

% Save figure to png, fig, and csv
if saveFigs
    exportgraphics(fig,[figuresDir 'png\' figFileName '.png']);
    savefig(fig,[figuresDir 'fig\' figFileName '.fig'],'compact');
    writematrix(csvData, [figuresDir 'csv\' figFileName '.csv']);
end
    
if ~keepFigsOpen
    close(fig);
end

%% Second simulation set: yield - varying screen strategy
figFileName = 'yield_modStrategy';
fig = figure('InvertHardcopy','off','Color',[1 1 1]);
csvData = [];
hold on

p = plot(0.1:0.1:0.9, tauParAbs10Mod(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParNirAbs10Mod(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoNirAbs10Mod(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoEAbs10Mod(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];


legend('$\tau_{PAR}$ ($a_{PAR}=0.1$)', ...
       '$\tau_{PAR}$ and $\tau_{NIR}$', ...
       '$\tau_{PAR}$ ($a_{PAR}=0.1$, $\tau_{NIR}$ = 0.3)', ...
       '$\tau_{PAR}$ ($a_{PAR}=0.1$, $\varepsilon^{Up}$ = 0.2)', ...
       'FontSize',fontSize, 'Location', 'se', 'Interpreter', 'latex', 'NumColumns', 2);

title('Total yield with modified screen parameters and strategy','FontSize',fontSize);
ylabel('Total yield (kg FW m^{-2} year^{-1})')
xlabel('Modified parameter value')
grid
set(gca,'FontSize',fontSize-2)
ylim([58 66])

fig.Units = 'centimeters';
fig.OuterPosition(3)=figSize(1);
fig.OuterPosition(4)=figSize(2);

% Save figure to png, fig, and csv
if saveFigs
    exportgraphics(fig,[figuresDir 'png\' figFileName '.png']);
    savefig(fig,[figuresDir 'fig\' figFileName '.fig'],'compact');
    writematrix(csvData, [figuresDir 'csv\' figFileName '.csv']);
end
    
if ~keepFigsOpen
    close(fig);
end

%% Second simulation set: EUE - varying screen strategy
figFileName = 'eue_modStrategy';
fig = figure('InvertHardcopy','off','Color',[1 1 1]);
csvData = [];
hold on

p = plot(0.1:0.1:0.9, tauParAbs10Mod(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParNirAbs10Mod(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoNirAbs10Mod(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoEAbs10Mod(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];


legend('$\tau_{PAR}$ ($a_{PAR}=0.1$)', ...
       '$\tau_{PAR}$ and $\tau_{NIR}$', ...
       '$\tau_{PAR}$ ($a_{PAR}=0.1$, $\tau_{NIR}$ = 0.3)', ...
       '$\tau_{PAR}$ ($a_{PAR}=0.1$, $\varepsilon^{Up}$ = 0.2)', ...
       'FontSize',fontSize, 'Location', 'nw', 'Interpreter', 'latex', 'NumColumns', 2);

title('Energy use efficiency with modified screen parameters and strategy','FontSize',fontSize);
ylabel('Energy use efficiency (g FW MJ^{-1})')
xlabel('Modified parameter value')
grid
set(gca,'FontSize',fontSize-2)
ylim([52 64])

fig.Units = 'centimeters';
fig.OuterPosition(3)=figSize(1);
fig.OuterPosition(4)=figSize(2);

% Save figure to png, fig, and csv
if saveFigs
    exportgraphics(fig,[figuresDir 'png\' figFileName '.png']);
    savefig(fig,[figuresDir 'fig\' figFileName '.fig'],'compact');
    writematrix(csvData, [figuresDir 'csv\' figFileName '.csv']);
end
    
if ~keepFigsOpen
    close(fig);
end

%% Second simulation set: gas use, yield, EUE - varying screen strategy
% Figure 2 in Katzin et al., Radiative properties of screens and energy saving in greenhouses

figFileName = 'Figure2_gasUseYieldEue_modStrategy';
fig = figure('InvertHardcopy','off','Color',[1 1 1]);
csvData = [];

subplot(3,1,1)
hold on

p = plot(0.1:0.1:0.9, tauParAbs10Mod(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParNirAbs10Mod(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoNirAbs10Mod(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoEAbs10Mod(1,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];

ylabel('Energy use (MJ m^{-2} year^{-1})')

title('A. Energy use for heating with modified screen parameters and strategy','FontSize',fontSize);
% xlabel('Modified parameter value (at the expense of reflection)')
grid
set(gca,'FontSize',fontSize-2)
ylim([1000 1300])

% Yield - varying screen strategy
subplot(3,1,2)
csvData = [];
hold on

p = plot(0.1:0.1:0.9, tauParAbs10Mod(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
% p = plot(0.1:0.1:0.9, tauParRef20Mod(2,:), '--o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
% csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParNirAbs10Mod(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoNirAbs10Mod(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoEAbs10Mod(2,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];


legend('$\tau_{PAR}$', ...
       '$\tau_{PAR}$ and $\tau_{NIR}$', ...
       '$\tau_{PAR}$ ($\tau_{NIR}$ = 0.3)', ...
       '$\tau_{PAR}$ ($\varepsilon^{Up}$ = 0.2)', ...
       'FontSize',fontSize, 'Location', 'se', 'Interpreter', 'latex', 'NumColumns', 2);

title('B. Total yield with modified screen parameters and strategy','FontSize',fontSize);
ylabel('Total yield (kg FW m^{-2} year^{-1})')
% xlabel('Modified parameter value')
grid
set(gca,'FontSize',fontSize-2)
ylim([58 66])

% EUE - varying screen strategy
subplot(3,1,3)
csvData = [];
hold on

p = plot(0.1:0.1:0.9, tauParAbs10Mod(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
csvData = [csvData p.YData'];
% p = plot(0.1:0.1:0.9, tauParRef20Mod(3,:), '--o', 'LineWidth', lineWidth, 'Color', cc(1,:)); 
% csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParNirAbs10Mod(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(2,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoNirAbs10Mod(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(3,:)); 
csvData = [csvData p.YData'];
p = plot(0.1:0.1:0.9, tauParLoEAbs10Mod(3,:), '-o', 'LineWidth', lineWidth, 'Color', cc(4,:)); 
csvData = [csvData p.YData'];

title('C. Energy use efficiency with modified screen parameters and strategy','FontSize',fontSize);
ylabel('Energy use efficiency (g FW MJ^{-1})')
xlabel('Modified parameter value (at the expense of reflection)')
grid
set(gca,'FontSize',fontSize-2)
ylim([52 64])

fig.Units = 'centimeters';
fig.OuterPosition(3)=figSize(1);
fig.OuterPosition(4)=figSize(2)*2;

% Save figure to png, fig, and csv
if saveFigs
    exportgraphics(fig,[figuresDir 'png\' figFileName '.png']);
    savefig(fig,[figuresDir 'fig\' figFileName '.fig'],'compact');
    writematrix(csvData, [figuresDir 'csv\' figFileName '.csv']);
end
    
if ~keepFigsOpen
    close(fig);
end

%% Second simulation set: hours screens used, total PAR, and yield
% Table 3 in Katzin et al., Radiative properties of screens and energy saving in greenhouses
figFileName = 'Table3_screenParYield_modStrategy';
csvData = ["Hours screen used (h/year)" ...
    "Total PAR at crop level (mol/m2/year)" ...
    "Yield (kg/m2/year)"];

csvData = [csvData; ...
    tauParAbs10Mod(4,:)' ... % Screen hours
    tauParAbs10Mod(5,:)' ... % PAR at crop level
    tauParAbs10Mod(2,:)' ... % Yield
    ];

csvData = [["tauPAR"; (0.1:0.1:0.9)'] csvData];
disp(csvData)

% Save data to csv
if saveFigs
    writematrix(csvData, [figuresDir 'csv\' figFileName '.csv']);
end
